# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-10-09 15:19
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('example', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='myuser',
            name='is_customer_admin',
            field=models.BooleanField(default=False, verbose_name='is customer admin'),
        ),
        migrations.AddField(
            model_name='myuser',
            name='language',
            field=models.CharField(blank=True, max_length=2, null=True, verbose_name='language'),
        ),
    ]
